@@ -21,6 +21,37 @@ import re,logging,time,datetime
 rx_template=re.compile(r"\{\{([^}]+)\}\}")
 rx_oid=re.compile(r"^(\d+\.){6,}")
 rx_mac_cisco=re.compile(r"^[0-9a-f]{4}\.[0-9a-f]{4}\.[0-9a-f]{4}$")
+##
+## Global functions for variables evaluation
+##
+
+##
+## Decode IPv4 from 4 octets
+##
+def decode_ipv4(s):
+    if len(s)==4:
+        return ".".join(["%d"%ord(c) for c in list(s)])
+    if is_ipv4(s):
+        return s
+    raise DecodeError
+##
+## Decode MAC address from 6 octets
+##
+def decode_mac(s):
+    if len(s)==6:
+        return "%02X:%02X:%02X:%02X:%02X:%02X"%tuple([ord(x) for x in list(s)])
+    if rx_mac_cisco.match(s):
+        s=s.replace(".","").upper()
+        return "%s:%s:%s:%s:%s:%s"%(s[:2],s[2:4],s[4:6],s[6:8],s[8:10],s[10:])
+    raise DecodeError
+##
+## Global variables dict
+##
+eval_globals={
+    "decode_ipv4" : decode_ipv4,
+    "decode_mac"  : decode_mac,
+}
+
 ##
 ## Exceptions
 ##
@@ -32,7 +63,10 @@ class Rule(object):
     def __init__(self,rule):
         self.rule=rule
         self.name=rule.name
-        self.re=[(re.compile(x.left_re,re.MULTILINE|re.DOTALL),re.compile(x.right_re,re.MULTILINE|re.DOTALL)) for x in rule.eventclassificationre_set.all()]
+        self.re=[(re.compile(x.left_re,re.MULTILINE|re.DOTALL),re.compile(x.right_re,re.MULTILINE|re.DOTALL)) for x in rule.eventclassificationre_set.filter(is_expression=False)]
+        self.expressions=[(x.left_re,compile(x.right_re,"inline","eval")) for x in rule.eventclassificationre_set.filter(is_expression=True)]
+        if not self.expressions:
+            self.expressions=None
     ##
     ## Return a hash of extracted variables for object o, or None
     ##
@@ -48,20 +82,8 @@ class Rule(object):
                 if not r_match:
                     return None
                 found=True
-                # Apply decoders if necessary
-                # Decoders are given as (?P<name__decoder>.....) patters
-                try:
-                    for gd in [l_match.groupdict(),r_match.groupdict()]:
-                        for k,v in gd.items():
-                            if "__" in k:
-                                k_name,decoder=k.split("__",1)
-                                vars[k_name]=getattr(self,"decode_%s"%decoder)(v) # Apply decoder
-                            else:
-                                vars[k]=v # Pass unchanged
-                except DecodeError:
-                    return None # No match when decoder failed
-                except AttributeError:
-                    return None # No match when decoder not found
+                vars.update(l_match.groupdict()) # Populate vars with extracted variables
+                vars.update(r_match.groupdict())
                 break
             if not found:
                 return None
@@ -80,7 +102,6 @@ class Rule(object):
     ##
     def decode_mac(self,s):
         if len(s)==6:
-            print repr(s)
             return "%02X:%02X:%02X:%02X:%02X:%02X"%tuple([ord(x) for x in list(s)])
         if rx_mac_cisco.match(s):
             s=s.replace(".","").upper()
@@ -171,7 +192,7 @@ class Classifier(Daemon):
                 return
             event_class=rule.rule.event_class
             event.event_class=event_class
-            if event_class.repeat_suppression and event_class.repeat_suppression_interval>0 and self.suppress_repeat(event):
+            if event_class.repeat_suppression and event_class.repeat_suppression_interval>0 and self.suppress_repeat(event,vars):
                 return # Event is suppressed, no further processing
             event_category=event_class.category
             event_priority=event_class.default_priority
@@ -201,6 +222,11 @@ class Classifier(Daemon):
         f_vars=dict(props) # f_vars contains all event vars, including original, extracted and resolved
         f_vars.update(vars)
         f_vars.update(resolved)
+        # Does rule contain additional expressions which are need to be calculated?
+        if rule and rule.expressions:
+            c_vars=dict([(x[0],str(eval(x[1],f_vars,eval_globals))) for x in rule.expressions]) # Evaluate all expressions
+            f_vars.update(c_vars) # Update var dicts
+            vars.update(c_vars)
         subject_template,body_template=self.templates[event_class.id]
         context=Context(f_vars)
         subject=subject_template.render(context)
@@ -283,7 +309,7 @@ class Classifier(Daemon):
     ## Suppress repeats.
     ## Return True if event is suppressed, False otherwise
     ##
-    def suppress_repeat(self,event):
+    def suppress_repeat(self,event,vars):
         event_class=event.event_class
         # Build keys
         kv={}
@@ -291,26 +317,23 @@ class Classifier(Daemon):
             if name in vars:
                 kv[name]=vars[name]
             else:
-                kv=None
-                break
-        if kv is not None:
-            r=[e for e in Event.objects.filter(
-                event_class=event_class,
-                managed_object=event.managed_object,
-                timestamp__gte=event.timestamp-datetime.timedelta(seconds=event_class.repeat_suppression_interval),
-                timestamp__lte=event.timestamp
-                ).exclude(id=event.id).order_by("-timestamp")
-                if e.match_data(kv)]
-            if len(r)>0:
-                pe=r[0]
-                logging.debug("Event #%d repeats event #%d"%(event.id,pe.id))
-                er=EventRepeat(event=pe,timestamp=pe.timestamp)
-                er.save()
-                pe.timestamp=event.timestamp
-                pe.save()
-                event.delete()
-                return True
-        return False
+                return False
+        r=[e for e in Event.objects.filter(
+            event_class=event_class,
+            managed_object=event.managed_object,
+            timestamp__gte=event.timestamp-datetime.timedelta(seconds=event_class.repeat_suppression_interval),
+            timestamp__lte=event.timestamp
+            ).exclude(id=event.id).order_by("-timestamp")
+            if e.match_data(kv)]
+        if len(r)>0:
+            pe=r[0]
+            logging.debug("Event #%d repeats event #%d"%(event.id,pe.id))
+            er=EventRepeat(event=pe,timestamp=pe.timestamp)
+            er.save()
+            pe.timestamp=event.timestamp
+            pe.save()
+            event.delete()
+            return True
     ##
     ## Main daemon loop
     ##
