@@ -7,7 +7,7 @@
 ##----------------------------------------------------------------------
 """
 """
-from noc.fm.rules.classification import ClassificationRule
+from noc.fm.rules.classification import ClassificationRule, Expression
 from noc.fm.rules.classes.phone import *
 ##
 ## Cisco.IOS Phone Call SNMP
@@ -25,4 +25,5 @@ class Cisco_IOS_Phone_Call_SNMP_Rule(ClassificationRule):
         (r"^1\.3\.6\.1\.4\.1\.9\.10\.25\.1\.4\.3\.1\.8\.\d+$",r"(?P<call_clearing>\S+)"),
         (r"^1\.3\.6\.1\.4\.1\.9\.10\.25\.1\.4\.3\.1\.3\.\d+$",r"^(?P<calling_number>\S*)$"),   # Sometimes empty
         (r"^1\.3\.6\.1\.4\.1\.9\.10\.25\.1\.4\.3\.1\.11\.\d+$",r"^(?P<disconnect_time>\d+)$"),
+        Expression("duration","int(disconnect_time)-int(connect_time)"),
     ]
\ No newline at end of file
