@@ -9,7 +9,7 @@
 """
 from django.conf.urls.defaults import *
 from django.contrib.auth.decorators import login_required
-from noc.main.views import index,logout,report,report_index,success,failure,menu
+from noc.main.views import index,logout,report,report_index,success,failure,menu,search
 
 urlpatterns = patterns ( None,
         (r"^$",        login_required(index)),
@@ -19,4 +19,5 @@ urlpatterns = patterns ( None,
         (r"success/$", login_required(success)),
         (r"failure/$", login_required(failure)),
         (r"menu/$",    login_required(menu)),
+        (r"search/$",  login_required(search)),
 )
